quarta-feira, 16 de janeiro de 2013

Sincronizando pastas no Windows 7 com o SyncToy 2.1

Profissionais de TI e Administradores de rede podem ter uma grande dor de cabeça com usuário que perdem dados do computador sem fazer backup. É difícil convencer mesmo os usuários mais experientes a salvar o seu trabalho remotamente e não apenas localmente.

O SyncToy é uma ferramenta disponibilizada pela Microsoft para ajudar nesse problema. Se você deseja sincronizar dados entre PCs ou até mesmo do seu computador com um dispositivo móvel, o SyncToy é a ferramenta ideal para ajudar nessa tarefa.

 
Se você costuma utilizar o pen drive para levar seus arquivos sempre com você, essa sincronização torna-se essencial. Com uma interface intuitiva, basta o usuário especificar as pastas que deseja manter a sincronização.

O SyncToy usa uma arquitetura de pastas emparelhadas, na qual você especifica um diretório esquerdo e outro direito. Você pode criar quantos pares de pastas desejar e sincronizar um ou todos eles com um único clique. Usando o agendador de tarefas do Windows é possível programar para que essa sincronização seja feita automaticamente em um horário pré determinado.

A versão 2.1 do programa é gratuita e traz suporte ao Windows 7 32 bits e 64 bits. Para fazer o download clique aqui.

 

Sincronização automática

Uma vez instalado, o SyncToy pode ser configurado da maneira que quiser. Você deve escolher duas pastas (ou dispositivos) diferentes e editar as informaçõs para que o programa execute a sincronização. Ali você define filtros e opções de sincronia, para que o SyncToy trabalhe em prol das suas necessidades.

Entretanto, para que o SyncToy faça o que você quiser, é preciso acessar o programa manualmente, escolher as opções (você pode fazer vários pares de pastas, de acordo com suas necessidades) e então mandar o programa executar a tarefa. Portanto, é hora de usar o agendador de tarefas do Windows.

Ao abrir o agendador, clique em “Criar tarefa básica” e aguarde alguns segundos. Sim, o seu computador vai parecer ter travado, mas não se preocupe.

 

Inicie uma nova tarefa

Na nova tarefa básica, insira as informações da atividade. No caso, inserimos o título como “Sincronização SyncToy” e colocamos uma pequena descrição do que aquela tarefa deve ser, caso você possua várias opções no agendador do computador.

Insira a tarefa e sua descrição

A seguir, é preciso escolher o chamado “disparador da tarefa”, ou seja, quando você deseja que a ação seja executada. Repare que existem poucas opções aqui, porém é possível editar o campo com informações mais precisas mais adiante.

Escolha o tempo no disparador de tarefas

Para este exemplo, escolhemos a opção diária, para que o agendador de tarefas conclua todos os dias a mesma atividade. Você é capaz de editar o dia do início da ação, hora e a repetição de dias em que isso se dará.

O agendador permite que você escolha a ação que deve ser executada pela tarefa. Neste caso, coloque a opção “Iniciar um programa” para que ele abra uma nova aba para edição.

Escolha iniciar um programa, no caso o Synctoy

Na primeira caixa de texto, entre o seguinte endereço, inclusive com as aspas: "C:\Program Files\SyncToy 2.1\SyncToyCmd.exe". A seguir, adicione o argumento “-R” (este, sem as aspas) para que ele execute todas as sincronizações criadas no SyncToy, porém uma de cada vez.

Se você preferir, o agendador pode mandar o SyncToy executar apenas uma das sincronizações criadas no programa, ao invés de todas. Coloque o argumento “-R” (sem aspas) seguido do nome da sincronização escolhida (em nosso caso, o nome “Teste agendador tarefas”). Para nomes compostos e que utilizam espaços, não se esqueça das aspas.

Encontre o caminho ou coloque o endereço

Caso você deixe de colocar as aspas na primeira caixa que mostra o caminho dos programas, uma notificação aparece no seu computador, confirmando a operação com os argumentos inseridos. Clique em “Não” para que o agendador de tarefas modifique as informações, adicionando as aspas onde deveria.

Clique em não para que o agendador insira as aspas

Ao final da tarefa, o sistema mostra ao usuário o resumo das informações ali dadas, de forma que você saiba exatamente o que ocorreu durante a o agendamento. Dessa forma, a sincronia já será feita de maneira automática, sem a necessidade de você rodar o SyncToy manualmente.

Resumo da criação

Editar a sincronização

Entretanto, algumas vezes pode ser necessário mudar a tarefa, de maneira que o sistema a execute em intervalos de tempo diferenciados, ou ainda, com outras configurações preestabelecidas por você.

Para isso, abra novamente o agendador de tarefas e clique em “biblioteca do agendador”. Todas as ações que foram criadas para o sistema se encontram ali. Portanto, busque aquela que você criou para o SyncToy e clique duas vezes para abrir todas as informações do processo. Caso esteja no modo de tela cheia, basta clicar uma vez na tarefa e editar as propriedades na própria tela, na janela logo abaixo.

Edite as opções do agendamento

Você também pode acessar as informações clicando em “Propriedades”, na lateral inferior direita do agendador. Da mesma forma, ali você é capaz de excluir, desabilitar, executar e finalizar a tarefa, mantendo o controle sobre aquilo que você configurou previamente.

Ali você tem mais opções para editar datas, repetições e muito mais. Essa caixa de diálogo é muito mais completa do que aquela criada na inserção da tarefa, portanto, use e abuse da personalização e deixe que a ação rode da forma mais interessante.

Condições para a tarefa

Nas abas de propriedades você pode editar também as condições com que o sistema trabalha para executar a tarefa. Para quem usa aparelhos que necessitam que precisam ser carregados na tomada, por exemplo, é possível editar as configurações para que o agendador execute aquela função mesmo com a energia somente da bateria.

Você também pode acessar o histórico de operações feitas pelo agendador (caso esteja em dúvida sobre a execução, de fato, da tarefa) ou, em caso de erro, tentar executar novamente a atividade em intervalos de tempo definidos.

Modifique as configurações da tarefa

Sincronize-se!

Vale a pena comentar que o agendador de tarefas é uma ferramenta que funciona não apenas com o SyncToy. Você é capaz de criar inúmeras atividades por ali, como desfragmentar o disco, rodar antivírus e muito mais. Basta um pouco de criatividade e conhecimento de quais são as ações que necessitam de agendamento no computador.

terça-feira, 13 de novembro de 2012

Dica: Verificação (dominio, dns, blacklist)

Fonte: http://brunodasilvalenga.wordpress.com/2012/02/29/dica-verificacao-dominio-dns-blacklist/

Autor: bruno da silva lenga

As vezes nos deparamos com alguns erros de DNS reverso, ou ate mesmo aquela blacklist chata que caímos. Ou apenas gostariamos de saber como nosso servidor está rodando atualmente (DNS, Email, WWW).
Para uma melhor verificação recomendo o uso do site abaixo.

http://www.ipok.com.br

Eele faz diversos testes em relação ao serviços de (DNS, Email, WWW).

Características:

  • Conjunto completo de ferramentas de dns
  • Mais de 40 testes online
  • Certifique a configuração de seu domínio
  • Veja o tempo de resposta de diversos serviços
  • Se seu firewall esta devidamente configurado
  • Análise diversos componentes de seu domínio:

Registro do domínio
Servidor DNS
Registro SOA
Servidor de email
Servidor Web (WWW)

  • Pesquisa em blacklists.
  • Verificação de dns reverso.
  • Cálculo de Netmask e Subnet
  • ISP podem usar o DNSReport e anexar como documentação para seus clientes.

 

E para verificação de BlackList recomendo os dois sites a seguir:

http://www.myiptest.com/staticpages/index.php/check-Blacklisted-IP-DNSBL

http://www.mxtoolbox.com/SuperTool.aspx?action=blacklist

Definição de parâmetros no log do SQUID

Fonte: http://brunodasilvalenga.wordpress.com/2012/02/29/definicao-de-parametros-no-log-do-squid/

Autor: bruno da silva lenga

Muitas vezes estamos verificando os Log’s do Squid, e nos deparamos com um requisição estranha do TCP_HIT ou TCP_DENIED, abaixo listo alguns parâmetros que o Squid pode informar e sua explicação.

TCP_HIT = Uma cópia válida do objeto pedido estava no cache.
TCP_MISS = O objeto pedido não estava no cache.
TCP_REFRESH_HIT = O objeto estava no cache, mas era antigo. Foi verificado e ele não foi alterado.
TCP_REF_FAIL_HIT = O objeto estava no cache, mas era antigo. O pedido para validar o objeto falhou, o objeto antigo foi retornado.
TCP_REFRESH_MISS = O objeto estava no cache, mas era antigo. Foi descarregado a cópia nova do objeto.
TCP_CLIENT_REFRESH = Foi uma requisição com a meta tag “no-cache”.
TCP_CLIENT_REFRESH_MISS = O browser forçou o proxy a verificar para ver se há uma versão nova do objeto.
TCP_IMS_HIT = O browser ja tinha uma cópia válida do objeto.
TCP_IMS_MISS = Foi feita um requisição para verificar se um objeto antigo tinha uma nova cópia.
TCP_SWAPFAIL = Era para o objeto estar no cache, mas não estava.
TCP_DENIED = A requisição foi negada.

segunda-feira, 5 de novembro de 2012

SQL Network Interfaces, error: 26 - Error Locating Server/Instance Specified

Fonte:http://blogs.msdn.com/b/sql_protocols/archive/2007/05/13/sql-network-interfaces-error-26-error-locating-server-instance-specified.aspx

Os usuários muitas vezes essa mensagem de erro quando a conexão a um servidor SQL e não sabe por onde começar a resolver o problema. Na maioria dos fóruns, as pessoas diz isso é porque a conexão remota não está habilitado no servidor. Isso não é exatamente correto. Na verdade, esta mensagem de erro dar aos clientes informações muito específicas e que a solução é bastante simples.

Primeiro de tudo, você receber essa mensagem de erro se você está tentando se conectar a um SQL Server instância nomeada. Por exemplo padrão, você nunca vê isso. Por quê? Porque mesmo que não nesta fase (ou seja, erro de localização do servidor / instância especificada), vamos continuar a tentar conectar usando valores padrão, por exemplo defaul porta TCP 1433, nome padrão tubo para Pipes nomeados. Você pode ver outra mensagem de erro devido a falha mais tarde, mas não essa mensagem de erro.

Cada cliente de tempo faz uma conexão com o SQL Server chamado instância, enviaremos um SSRP pacote UDP para o servidor da máquina porta UDP 1434. Precisamos deste passo para saber informações de configuração da instância do SQL, por exemplo, os protocolos habilitado, a porta TCP, etc nome do pipe Sem essas informações, o cliente não sabe como conectar o servidor e ele falhar com esta mensagem de erro especificado.

Numa palavra, o motivo que receber essa mensagem de erro é a pilha do cliente não poderia receber SSRP pacote UDP resposta do SQL Browser. É fácil para isolar o problema. Aqui estão os passos:

1) Verifique se o nome do servidor está correto, por exemplo, nenhum erro de digitação no nome.

2) Verifique se o nome da instância está correto e não há realmente uma instância como em sua máquina-alvo.[Update: Alguns aplicação converte \ \ para \. Se você não tem certeza sobre o seu pedido, por favor tente o Servidor \ Instância e Server \ \ Instância em sua seqüência de conexão ]

3) Certifique-se que a máquina servidor está acessível, por exemplo, podem ser DNS resolver corretamente, você é capaz de executar ping no servidor (nem sempre verdadeira).

4) Faça serviço Navegador certeza SQL está em execução no servidor.

5) Se o firewall estiver habilitado no servidor, você precisa colocar sqlbrowser.exe e / ou porta UDP 1434 em exceção.

Uma vez que você é feito os passos, você não deve ver esta mensagem de erro mais. Você ainda pode deixar de ligar o seu servidor SQL, mas a mensagem de erro deve ser diferente e você tem um problema diferente agora. [ Atualização: Se continuar a falhar, você pode substituir servidor \ instância com tcp: servidor \ instância e / ou np: instância do servidor \ e ver se ele consegue com protocolo TCP ou NP. Dessa forma, você pode isolar o problema um pouco. ]

Há um caso canto onde você ainda pode falhar depois de verificado o passo 1) -4). Isso acontece quando a) o servidor é uma instância nomeada em cluster ou em uma máquina multi-homed, e b) o seu cliente é uma máquina Vista com firewall. Eu expliquei os detalhes em: Unable to connect to a SQL Server named instance on a cluster

[ Atualização maio 2009 ] Meu colega encontrou uma ferramenta online bem que poderia ser muito útil para os usuários de isolar questões relacionadas com esta mensagem de erro. Você pode baixar a partir de PortQry http://support.microsoft.com/kb/832919 , execute "portqry.exe-n nome_do_seu_servidor-p udp-e 1434". Se este comando retorna informações e que contém a instância alvo, então você pode descartar possibilidade 4) e 5) acima, ou seja, você tem um navegador do SQL executado e seu firewall não bloqueia SQL Browser pacote UDP. Neste caso, você pode verificar outra questão, por exemplo, seqüência de conexão errada.

sexta-feira, 3 de agosto de 2012

Como utilizar a ferramenta PSEXEC

Utilitários como o Telnet e programas de controle remoto, como o  PCAnywhere, da Symantec, permitem que você execute programas em sistemas remotos, mas podem ser difíceis de configurar e requerem que você instale o software cliente nos sistemas remotos que desejar acessar. O PsExec é um substituto leve do telnet, que lhe possibilita executar processos em outros sistemas, completar aplicativos de console com total interatividade, sem ter que instalar manualmente o software cliente. Os usos mais poderosos do PsExec incluem iniciação de prompts de comando interativos em sistemas remotos e ferramentas de habilitação remota, como o IpConfig, que, de outra forma, não teria a capacidade de mostrar informações sobre sistemas remotos. Eu mesmo já usei o PsExec para remover programas remotamente de computadores no domínio. Os truques para isso virão num próximo post.

Instalação
Copie o PsExec no seu caminho do executável. Digite “psexec” para exibir a sintaxe de uso. O PsExec funciona no Windows Vista, no NT 4, no Win2K, no Windows XP e no Server 2003, incluindo as versões de x64 do Windows.
Sintaxe:


psexec [\\computer[,computer2[,...] | @file][-u user [-p psswd]][-n s][-l][-s|-e][-x][-i [session]][-c [-f|-v]][-w directory][-d][-][-a n,n,... ] cmd [arguments]
computer : Direcione o PsExec para executar o aplicativo no computador ou nos computadores especificados. Se você omitir o nome do computador, o PsExec executa o aplicativo no sistema local e, se você inserir o nome do computador como “\\*”, o PsExec executa os aplicativos em todos os computadores do domínio atual.


@file : Direciona o PsExec para executar o comando em cada computador listado no arquivo de texto especificado.

-a
: Separa processadores nos quais o aplicativo pode ser executado sem vírgulas, onde 1 é a CPU com o número mais baixo. Por exemplo, para executar o aplicativo na CPU 2 e na CPU 4, digite: “-a 2,4″.
-c : Copia o programa especificado no sistema remoto para execução. Se você omitir esta opção, o aplicativo deve estar no caminho do sistema, no sistema remoto.
-d : Não espere o aplicativo encerrar. Só use esta opção para aplicativos não interativos.
-e : Não carrega o perfil da conta especificada.
-f : Copia o programa especificado no sistema remoto, mesmo que o arquivo já exista neste local.
-i : Executa o programa de modo que ele interaja com a área de trabalho da sessão especificada no sistema remoto. Se nenhuma sessão for especificada, o processo será executado na sessão de console.
-l :Executa o processo como usuário limitado (remove o grupo Administrators (Administradores) e permite apenas privilégios atribuídos ao grupo Users (Usuários). No Windows Vista o processo é executado com Baixa integridade.

-n : Especifica o tempo limite em segundos para conectar-se aos computadores remotos.
-p : Especifica uma senha opcional para o nome de usuário. Se omitir isso, você será solicitado a inserir uma senha oculta.
-s : Executa o processo remoto na conta System (Sistema):
-u : Especifica um nome de usuário opcional para o logon no computador remoto.
-v : Copia o campo especificado somente se ele tiver um número de versão superior ou se for mais recente do que a versão do sistema remoto.
-w : Define o diretório de trabalho do processo (relativo ao computador remoto).
-x : Exibe a interface do usuário na área de trabalho do Winlogon (apenas no sistema local).
-priority : Especifica -low, -belownormal, -abovenormal, -high ou -realtime para executar o processo em uma prioridade diferente.
program : Nome do programa para executar.
arguments : Argumentos para transferir (observe que os caminhos de arquivo devem ser caminhos absolutos no sistema de destino).

Você pode colocar entre aspas os aplicativos que tiverem espaços no nome, por exemplo: “psexec \\marklap “c:\long name\app.exe”. A entrada só é transferida para o sistema remoto quando você pressiona a tecla Enter e digita Ctrl-C para encerrar o processo remoto.

Se você omite um nome de usuário, o processo remoto é executado na mesma conta de onde você executa o PsExec, mas, como o processo remoto é pessoalizado, ele não terá acesso a recursos de rede no sistema remoto. Quando você especifica um nome de usuário, o processo remoto é executado na conta especificada e tem acesso a qualquer recurso de rede a que a conta tenha acesso. Observe que a senha é transmitida em texto não criptografado para o sistema remoto.

Você pode usar a versão atual do PsExec como uma substituição Runas quando você direciona o sistema local, porque o PsExec não requer que você seja um administrador.

 

Exemplos

O seguinte comando inicia um prompt de comando interativo em \\marklap: psexec \\marklap cmd

Este comando executa o IpConfig no sistema remoto com a opção /all, e exibe a saída resultante localmente:

psexec \\marklap ipconfig /all

Este comando copia o programa test.exe no sistema remoto e o executa interativamente:

psexec \\marklap -c test.exe

Especifica o caminho completo para um programa que já esteja instalado em um sistema remoto, se ele não estiver no caminho do sistema.

psexec \\marklap c:\bin\test.exe

Executa o Regedit interativamente na conta System para exibir o conteúdo das chaves SAM e SECURITY:

psexec -i -d -s c:\windows\regedit.exe

Para executar o Internet Explorer com privilégios de usuário limitado, use este comando:

psexec -l -d “c:\program files\internet explorer\iexplore.exe”


O PsExec faz parte de um kit cada vez maior de ferramentas de linha de comando da Sysinternals que auxiliam na administração de sistemas Windows NT/2K locais e remotos, chamadas PsTools.

 

Download:

Download

   Download PsTools

          (1.60 MB)

sexta-feira, 8 de junho de 2012

Using SSH Tunnel with PuTTY to browse internet hiding your IP address

 

If you have access to SSH on a remote server (dedicated server, vps or shell account), you can browse the internet over the IP address hiding your original IP address.

This can be useful for many scenarios like -

IP based authentication over dynamic IP:
In many cases for security reasons we use restrict access only to some selected IP addresses. For example, admin area of a blog, forum, billing system or help desk can be protected with IP based authentication.
But what if you are on dynamic IP? You can allow your users (or yourself) first to ssh to a server with static ip and then access your restricted web app over the ssh tunnel. Your restricted web app will get the remote server IP as the user IP.

Technical limitations related to shared/dynamic IP:
In many places (specially in Bangladesh) ISPs provide the clients only with dynamic or shared IP address. In some places access are limited by number of access per IP address.
For example, download services like RapidShare will not allow you to download a file when someone else is downloading a file over your shared IP. You can easily bypass such limits using this SSH Tunneling.
Just last night I had to use ssh tunneling to create a couple of Live IDs (passport.net) as Micro$oft was not allowing to create any from my local ISP IP :S

Being a cool geek:
Or you can use it just to surprise your friends (who actaully checks for your ip =P) by showing your domain on you email and forum posts ;)

Anyways… enough of possible “usage”. If you are reading this, I bet you already “need it” =P

Now to get straight into the tutorial.

What you need?
1. PuTTY SSH Client. (Can be downloaded from
here.)
2. Firefox Web Browser. (Can be downloaded from
here
.)
3. SSH access to a unix/linux server. (Now thats something I can’t give you ;) )

Now, first run PuTTY. You should be on the “PuTTY Configuration” window. On the “Host Name (or IP address)” field, type the hostname or IP address of your remote server. And select “Connection type” as “SSH“. The port should get automatically selected to 22.
PuTTY - Remote Server Hostname

Then, in the left-hand menu, click on “SSH“. In “Protocol options“, tick “enable compression” and set your preferred SSH version to “2“.
PuTTY SSH Connection Option

Now expand the “SSH” menu and select the “Tunnels” sub-menu.
PuTTY - Tunnels Menu

Now under the “Tunnels” menu (Options controlling SSH port forwarding), in the “Source port” field, type in a source port. Here I am using 4567. But you can use anything. Then select “Dynamic” as “Destination” and click the “Add” button.
PuTTY - Port Forwarding

After clicking the “Add” button the newly added forwarded port should get listed under “Forwarded ports” list.
PuTTY SSH Tunnel - Port Forwarding

Now, go back to the “Session” tab at the top of the menu, give the new connection a name (here i used My SSH Proxy) and click on the “Save” button.
PuTTY - My SSL Proxy

Congrats! we are done with the PuTTY configuration.

From now on you can use this connection to login to your server. After login, you winn be able to use the connection as SSH Tunnel.

But before starting to browse internet using the IP address of the server, we need to configure firefox settings.

Lets fire up the fox and go to “Tools > Options…”
Firefox - Tools Options Menu

Now click the Advanced icon (on the upper-right of the dialog), and select the Network tab. Then click on the “Settings…” button.
Firefox Advanced Network Settings

This will brings up the “Connection Settings” dialog. On this dialog click the “Manual proxy configuration” radio button, then put the address 127.0.0.1 in the “SOCKS Host” field. In the “Port” field enter the port you used when configuring your SSH tunnel with Putty. In my case this port is 4567.
Firefox - Manual Proxy Configuration

Click the “OK” buttons to accept your changes.

Done!

Now make sure you have already logged in to the server using the connection we created with PuTTY and start browsing with Firefox.

You can visit a IP address identifier site like WhatIsYourIp.com or Whois.com.bd to check which IP address firefox is showing.

quarta-feira, 30 de maio de 2012

Projeto para Android

Fonte: http://blog.thiagobaptista.com/desenvolvimento/2011/06/corta-conta-uma-aplicacao-completa-em-android-parte-2-setup/#comment-302

Autor: Thiago Baptista

Nesta segunda parte dessa série que pretende criar uma aplicação completa em Android (veja a primeira parte aqui) vamos fazer algo bem trivial, criar o setup da aplicação no Eclipse, utilizando a SDK do Android e o plugin ADT.

1. O primeiro passo é ter baixado e instalado o SDK do Android do site oficial. Se você ainda não fez isso, vá em http://developer.android.com/sdk/index.html, selecione o arquivo de acordo com sua plataforma e baixe-o.

Site de download do Android SDK

Site de download do Android SDK

2. O segundo passo é instalar o plugin do Eclipse para desenvolvimento Android, o ADT, se já não tiver ele em seu Eclipse. Faça isso, em sua IDE, clicando em Help > Install New Software… (Dica: marque a combo “Hide items that are already installed” para não acabar se enrolando). Na tela que se abre, no campo “Work with:“, insira a URL do update site: https://dl-ssl.google.com/android/eclipse/. Quando o plugin aparecer listado, selecione-o e instale-lo (Next… next… finish, você sabe o esquema ;) ).

Selecionando o plugin ADT

Selecionando o plugin ADT

3. Agora, é necessário que o SDK Manager baixe as SDKs e recursos extras necessários. Se o plugin ADT fora instalado corretamente, você poderá acessar o Manager clicando em Window > Android SDK and AVD Manager. Clique na aba “Avaliable packages” e selecione a combo “Android Repository“. Se você não quiser baixar todas as versões do SDK, por exemplo se quiser criar aplicações para apenas uma API Level, você pode personalizar a escolha explodindo a seleção e marcando os pacotes individuais.

O menu do Android SDK and ADV Manager

O menu Android SDK and AVD Manager

Quando estiver pronto, clique em “Install Selected“. O Manager irá baixar e instalar o que foi selecionado. Atenção, essa operação pode demorar um pouco, pois os pacotes são grandes. Ao terminar, é bom reiniciar o Eclipse para evitar erros na hora de rodar o projeto pela primira vez.

4. Com tudo pronto, é hora de criar o projeto no Eclipse. Essa parte é bem tranquila, clicando em File > New > Other… > Android > Android Project.

5. No campo “Project name:” vamos colocar o nome “CortaConta”. Preste atenção na lista em “Build Target“; ela deverá listar todas as SDKs instaladas em seu ambiente. Para esse projeto iremos utilizar a plataforma 2.1-update1 (API Level 7), que é hoje a mais comum de se encontrar na “população” de dispositivos Android, além de ser uma versão estável da API.

6. No campo “Properties“, no subcampo “Application name:“, coloque “Corta Conta”, assim com espaço entre as palavras, pois esse é o nome real da aplicação, que aparecerá em labels e em menus. Em “Package name:” coloque “com.thiagobaptista.cortaconta”. Deixe a Activity com o nome “CortaContaActivity” mesmo. Pra encerrar, clique em “Finish“.

Criando o novo projeto no Eclipse

Criando o novo projeto no Eclipse

Pronto! Nosso projeto está configurado e preparado para começarmos a desenvolver. Se tudo ocorreu bem, a estrutura de pastas e arquivos do projeto deve estar assim:

Estrutura de pastas e arquivos do projeto

Estrutura de pastas e arquivos do projeto

7. Vamos colocar o projeto pra rodar. Para isso, é preciso antes configurar um emulador em sua IDE (é possível testar a aplicação direto em seu dispositivo Android; mais pra frente, em outra postagem, explico como fazer isso). Para isso, abra o Manager e vá na aba “Virtual devices” (que é a selecionada por default). Clique em “New…”

8. Na tela que se abre, no campo “Name:” digite o nome que você quiser para esse emulador; no campo “Target:” escolha a API (no nosso caso a “Android 2.1-update1 – API Level 7“); no “SD Card:“, subcampo “Size:” coloque o mínimo em megabytes para simular um SD Card, que é de 9 MB. Por fim, clique em “Create ADV“.

Criando um novo dispositivo virtual

Criando um novo dispositivo virtual

9. Clique agora, no Eclipse, com o botão direito do mouse sobre o projeto da aplicação e selecione Run As… > Android Application. Se está tudo certo, o emulador abrirá e começará o processo de boot do dispositivo. Não se preocupe se nessa primeira execução demorar um pouco para terminar o boot, acontece assim porque o emulador é recém-criado e está configurando o SD Card virtual.

O emulador funciona como um dispositivo Android touchscreen comum, e o mouse faz as vezes de nossos dedos. Depois do boot, como em um dispositivo Android qualquer a tela se encontra travada. Clique e arraste o botão na tela para destravá-la. Nossa aplicação deverá aparecer na tela do emulador.

A tela do emulador.

A tela do emulador. Clique e arraste a barrinha com o cadeado para destravar, como num dispositivo real

Agora sim! O famigerado “Hello World” aparece mais uma vez para nós, como arauto de um promissor futuro no desenvolvimento móvel e de código aberto…

Não subestime a maldição!

Não subestime a maldição!

Na próxima postagem dessa série, faremos o levantamento inicial de requisitos dessa aplicação, mas de forma ágil, que permita seu crescimento natural e não atrapalhe nosso desenvolvimento.

Enquanto isso, seria interessante você dar uma olhada nos arquivos gerados pelo Eclipse e estudá-los. Tente, por exemplo, mudar o texto padrão do “Hello World“!

sexta-feira, 25 de maio de 2012

Excel – Como contar valores repetidos

Temos uma tabela com vários valores repetidos

image

Temos então 27 registos dos quais 22 são únicos. Como descobrimos isto.

Com a fórmula em C2 : =SOMA(1/CONTAR.SE(A2:A28;A2:A28))

Não esquecer que se trata de um cálculo matricial pelo que é necessário inserir os símbolos {} da maneira correta.

Clique na Barra de fórmulas e digite CTRL + SHIFT + ENTER

Para obter o nº de duplicados à frente de cada um dos valores, usamos a fórmula em cada célula de B2 a B28 : =CONTAR.SE(A$2:A$28;A$2:A$28)

segunda-feira, 21 de maio de 2012

Passar colunas pra linhas e vice-versa (EXCEL)

Tenho um ficheiro em excel com centenas de linhas e algumas colunas. O problema é que para o efeito que quero, terei de colocar em linha o que está em coluna e vice-versa!!!
Temos que fazer uma "Matriz Transposta". Para isso o Excell tem a função

Vamos ver então a ajuda do próprio Ecell

Método 1 – Apenas copiar e colar especial

Selecionar a matriz e fazer colar especial. Selecionar transpor

image 

Selecionar transpor e o sítio onde queremos colar

image

Método 2 - Função TRANSPOR

A função TRANSPOR devolve um intervalo de células vertical como um intervalo horizontal ou vice-versa. A função TRANSPOR deve ser introduzida como uma fórmula de matriz num intervalo que tenha o mesmo número de linhas e colunas, respectivamente, que o intervalo de origem. Utilize TRANSPOR para mudar a orientação vertical e horizontal de uma matriz ou intervalo numa folha de cálculo.

Sintaxe

TRANSPOR(matriz)

A sintaxe da função TRANSPOR tem o seguinte argumento:


  • matriz Necessário. Uma matriz ou um intervalo de células de uma folha de cálculo que pretende transpor. A transposição de uma matriz é criada através da utilização da primeira linha da matriz como a primeira coluna da nova matriz, a segunda linha da matriz como a segunda coluna da nova matriz e assim sucessivamente.

Exemplo


image

No entanto se dermos Enter, o resultado da fórmula é #Valor!

Importante A fórmula apresentada no exemplo tem de ser introduzida como uma fórmula de matriz para que a função TRANSPOR funcione como esperado. Depois de copiar o exemplo para uma folha de cálculo em branco, seleccione o intervalo A5:A7, começando com a célula de fórmula. Prima F2 e, em seguida, CTRL+SHIFT+ENTER. Se a fórmula não for introduzida como uma fórmula de matriz, o único resultado é 1.



Devemos então selecionar uma matriz de 8 linhas e 5 colunas que deverá começar em A9 (onde temos a função TRANSPOR).


image


Clicamos agora na fórmula para a editar e com a formula em edição clicamos em ctrl+shift+enter


e obtemos as nossa coluna transposta


image

segunda-feira, 14 de maio de 2012

Configurar Pen banda larga operadores móveis

Criar perfis para as 3 redes com os dados abaixo:

 

TMN (testado e a funcionar)

Dial Number:  *99#
APN: internet
Nome de Utilizador: tmn
Palavra-passe: tmnnet

 

Vodafone (testado e a funcionar)

Dial Number: *99#
APN: internet.vodafone.pt   (ou net2.vodafone.pt)
Nome de Utilizador: vodafone
Palavra-passe: vodafone

 

Optimus Kanguru:

Dial Number: *99#
APN:
myconnection

 

Nota: Há quem diga que o Username e password não são necessários(nos 3 operadores) . Não sei. Não testei